/*********************************************************************************

Copyright(c) 2015 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*
 * Project		MCAPI+MDMA example - Dual Sharc Talkthrough
 * Description	The purpose of this project is to demonstrate the MCAPI and MDMA
 * 				Inter-Processor Communications (IPC) methods. The project takes
 * 				four channels of audio from the ADAU1979 CODEC into
 * 				Sharc 0 (core 1) L1 SRAM and sends the data directly to
 * 				Sharc 1 (core 2) L1 SRAM using MDMA during runtime. MCAPI is used
 * 				to initialize and synchronize the MDMA channel during initialization.
 * 				The ARM is used during initialization but is not used during runtime.
 *
 * File
 * Description	This is the first user code run out of reset main().
 * 				The ARM runs first out of reset, initializes the SPU, GPIO, and power.
 * 				The board softswitches are also configured by the ARM.
 * 				The Sharcs are held in reset until the ARM completes its initialization.
 * 				After the ARM lets the Sharcs run, it sits in a loop.
 *
 */
#ifndef __MULTICORETALKTHRUSHARCSHARC_CORE0_H__
#define __MULTICORETALKTHRUSHARCSHARC_CORE0_H__

/* Macro to specify delay count for ADC/DAC reset */
#define DELAY_COUNT             (100000u)

/* Add your custom header content here */
#define MEMCOPY_STREAM_ID           ADI_DMA_MEMDMA_S0       /* Stream 0 */
/* SPU PID for MDMA0 Source */
#define MDMA0_SRC_DMA8_SPU_PID      (88u)
/* SPU PID for MDMA0 Destination */
#define MDMA0_DST_DMA9_SPU_PID      (89u)

/* Core clock is generated from CGU0 */
#define CGU_DEV                 (0)
#define MHZ                     (1000000u)
#define CLKIN                   (25u * MHZ)
#define CORE_MAX                (450u * MHZ)
#define SYSCLK_MAX              (225u * MHZ)
#define SCLK_MAX                (112u * MHZ)

/* SPU Peripheral ID */
#define	SPORT_4A_SPU_PID		    (23u)
#define	SPORT_4B_SPU_PID		    (24u)
#define	SPORT_4A_DMA10_SPU_PID		(74u)
#define	SPORT_4B_DMA11_SPU_PID		(75u)

#define PIN_MASK (0x0000007Fu)
#define PIN_LEN  (7u)

#define DATA_MASK (0x0000003Fu)
#define DATA_LEN  (6u)

#define CLK_MASK (0x0000001Fu)
#define CLK_LEN  (5u)

#define FS_MASK (0x0000001Fu)
#define FS_LEN  (5u)

#define PE_MASK (0x0000003Fu)
#define PE_LEN  (6u)

/* IF (Debug info enabled) */
#if defined(ENABLE_DEBUG_INFO)
#define DBG_MSG                     printf
#else
#define DBG_MSG(...)
#endif

#endif /* __MULTICORETALKTHRUSHARCSHARC_CORE0_H__ */
