/*********************************************************************************

Copyright(c) 2015 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*
 * Project		MCAPI+MDMA example - Dual Sharc Talkthrough
 * Description	The purpose of this project is to demonstrate the MCAPI and MDMA
 * 				Inter-Processor Communications (IPC) methods. The project takes
 * 				four channels of audio from the ADAU1979 CODEC into
 * 				Sharc 0 (core 1) L1 SRAM and sends the data directly to
 * 				Sharc 1 (core 2) L1 SRAM using MDMA during runtime. MCAPI is used
 * 				to initialize and synchronize the MDMA channel during initialization.
 * 				The ARM is used during initialization but is not used during runtime.
 *
 * File
 * Description	This filter is executed on the input audio frames.
 * 				The result is copied to the other Sharc via MDMA.
 *
 */
#include <sys/platform.h>
#include <sys/adi_core.h>


void InputSeriesFilter( int8_t *InputBuffer, int8_t *OutputBuffer, uint32_t BytesToProcess )
{
	int8_t *pSrc = InputBuffer;
	int8_t *pDst = OutputBuffer;

	// Talthrough
	for(uint32_t i=0; i<BytesToProcess;i++)
	{
		*pDst++ = *pSrc++;

	}
}


