/*********************************************************************************

Copyright(c) 2015 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*
 * Project		MCAPI+MDMA example - Dual Sharc Talkthrough
 * Description	The purpose of this project is to demonstrate the MCAPI and MDMA
 * 				Inter-Processor Communications (IPC) methods. The project takes
 * 				four channels of audio from the ADAU1979 CODEC into
 * 				Sharc 0 (core 1) L1 SRAM and sends the data directly to
 * 				Sharc 1 (core 2) L1 SRAM using MDMA during runtime. MCAPI is used
 * 				to initialize and synchronize the MDMA channel during initialization.
 * 				The ARM is used during initialization but is not used during runtime.
 *
 * File
 * Description	The two Sharcs come out of reset at approximately the same time.
 * 				This file contains main() for Sharc 2. Sharc 2 manages the DAC.
 * 				The DAC is enabled when the first frame is received from Sharc 1.
 * 				This synchronizes the ADC and the DAC. Audio frames coming from
 * 				Sharc 1 cause an interrupt. The interrupt handler runs the output
 * 				filter. The result is copied into a DAC ping pong buffer.
 *
 */
#ifndef __MULTICORETALKTHRUSHARCSHARC_CORE2_H__
#define __MULTICORETALKTHRUSHARCSHARC_CORE2_H__

extern void OutputSeriesFilter( int8_t *InputBuffer, int8_t *OutputBuffer, uint32_t BytesToProcess );

/* Macro to specify delay count for ADC/DAC reset */
#define DELAY_COUNT             (100000u)

/*
 * DAC settings
 */
/* DAC Master clock frequency */
#define ADAU1962A_MCLK_IN       (24576000u)
/* DAC sample rate */

/* ADAU1962A SPORT config parameters */
#define LR_B_CLK_MASTER_1962    (true)
#define BCLK_RISING_1962 	    (true)

#ifdef TDM_MODE
#define LRCLK_HI_LO_1962        (false)
#else
#define LRCLK_HI_LO_1962        (true)
#endif
/* Sine wave parameters */
#define REFERENCE_FREQ 				(3000u)
#define SAMPLE_RATE   			(48000u)
#define SAMPLES_PER_PERIOD 			(SAMPLE_RATE) / (REFERENCE_FREQ)
#define SAMPLE_SIZE 				(4u)

#define NUM_CHANNELS				(4u)

/* Macro to set buffer size */
//#define AUDIO_BUFFER_SIZE 	        (SAMPLES_PER_PERIOD * NUM_CHANNELS * SAMPLE_SIZE * 4u)
#define AUDIO_BUFFER_SIZE 	        (SAMPLES_PER_PERIOD * NUM_CHANNELS * SAMPLE_SIZE)

/* IF (Debug info enabled) */
#if defined(ENABLE_DEBUG_INFO)
#define DBG_MSG                     printf
#else
#define DBG_MSG(...)
#endif

#endif /* __MULTICORETALKTHRUSHARCSHARC_CORE2_H__ */
