/*********************************************************************************

Copyright(c) 2015 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*
 * Project		MCAPI+MDMA example - Dual Sharc Talkthrough
 * Description	The purpose of this project is to demonstrate the MCAPI and MDMA
 * 				Inter-Processor Communications (IPC) methods. The project takes
 * 				four channels of audio from the ADAU1979 CODEC into
 * 				Sharc 0 (core 1) L1 SRAM and sends the data directly to
 * 				Sharc 1 (core 2) L1 SRAM using MDMA during runtime. MCAPI is used
 * 				to initialize and synchronize the MDMA channel during initialization.
 * 				The ARM is used during initialization but is not used during runtime.
 *
 * File
 * Description	In order to use MDMA to transfer data between cores, the driver needs
 * 				to be setup in a particular sequence. Sharc 1 is the source or master
 * 				core. It opens the MDMA channel on a specific stream, then uses MCAPI
 * 				to send the Sid to Sharc 2. Sharc 2 is the destination or slave core.
 * 				After receiving the Sid, the slave core installs an interrupt handler
 * 				to handle the MDMA completion event. Audio frames cannot be sent to the
 * 				slave core until the slave sends a message to the master core saying the
 * 				interrupt handler is installed. After the slave core installs its interrupt
 * 				handler, it sends the destination buffer address to the master core. After
 * 				the master core receives the destination buffer address, it starts sending
 * 				audio frames to the destination buffer address.
 *
 */
#ifndef SHARCLINKINTERFACE_H_
#define SHARCLINKINTERFACE_H_

/*=============  MCAPI    =============*/
/* MCAPI Domain number. Zero is the only supported domain at present. */
#define DOMAIN 0u
#define NODE_CORE_0 1u
#define NODE_CORE_1 2u

#define MEMCOPY_STREAM_ID           ADI_DMA_MEMDMA_S0       /* Stream 0 */
/* SPU PID for MDMA0 Source */
#define MDMA0_SRC_DMA8_SPU_PID      (88u)
/* SPU PID for MDMA0 Destination */
#define MDMA0_DST_DMA9_SPU_PID      (89u)


#define SHARC_LINK_SUCCESS			0
#define SHARC_LINK_ERROR			-1
#define SHARC_LINK_MCAPI_ERROR		-2

extern int SHARC_linkSlaveInit( ADI_INT_HANDLER_PTR pfHandler, void *DMASlaveDestinationAddress );

#define MCAPI_VERBOSE			// Define for verbose MCAPI messages
#if 1
#define DEBUGMSG                     fprintf
#else
#define DEBUGMSG(...)
#endif

#endif /* SHARCLINKINTERFACE_H_ */
